#include <fcntl.h>

#include <qregexp.h>
#include <qtimer.h>

#include <kapplication.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>
#include <kwin.h>
#include <kwinmodule.h>

#include "kpassivepopup.h"

static KCmdLineOptions options[] =
{
  { "!+message", I18N_NOOP("Message to display."), 0 },
  { "window <regexp>", I18N_NOOP("A regular expression matching the window title.\n"
                  "If you do not specify one, then the very first window\n"
				 "to appear will be taken. Not recommended!"), 0 },
  { "msgtitle <text>", I18N_NOOP( "Sets the title of the message" ), 0 },
  { "timeout <millis>", I18N_NOOP( "The message will be hidden automatically after the specified\n" \
				   "number of milliseconds." ), "5000" },
  { 0, 0, 0 }
};

int main( int argc, char *argv[] )
{
  KAboutData aboutData( "ktaskmessage", I18N_NOOP( "KTaskMessage" ),
			"KTaskMessage 0.1", 
			I18N_NOOP( "Command-line tool for displaying passive popups." ),
			KAboutData::License_GPL,
			"(C) 2002 Richard Moore (rich@kde.org)" );
  aboutData.addAuthor( "Richard Moore", 0, "rich@kde.org" );

  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.

  KApplication app;
  QObject::connect( &app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()) );

  //
  // Process Args
  //
  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

  // Read the message
  QString match = args->getOption( "window" );
  QString msgTitle = args->getOption( "msgtitle" );
  QString timeoutStr = args->getOption( "timeout" );

  QString msg;
  for ( int i = 0; i < args->count(); i++ )
    msg += QCString( args->arg(i) ) + " ";

  // Find the window
  KWinModule *kwinmodule = new KWinModule( 0 );
  QValueList<WId>::ConstIterator it;
  QRegExp pattern( match );
  
  for ( it = kwinmodule->windows().begin(); it != kwinmodule->windows().end(); ++it ) {
      if ( pattern.search( KWin::info( *it ).name ) != -1 )
	  break;
  }

  // Show the popup
  QPixmap icon;
  icon.load( "hi32-app-logtracker.png" );

  bool ok;
  int timeout = timeoutStr.toInt( &ok );
  KPassivePopup *pop = KPassivePopup::message( msgTitle, msg, icon,
					       *it, "passive_popup",
					       ok ? timeout : -1 );
 
  return app.exec();
}


